@@ -1,18 +1,13 @@
 package File::Spec::Mac;
 
 use strict;
-use vars qw(@ISA $VERSION);
+use Cwd ();
 require File::Spec::Unix;
 
-$VERSION = '3.33';
-$VERSION = eval $VERSION;
+our $VERSION = '3.75';
+$VERSION =~ tr/_//d;
 
-@ISA = qw(File::Spec::Unix);
-
-my $macfiles;
-if ($^O eq 'MacOS') {
-	$macfiles = eval { require Mac::Files };
-}
+our @ISA = qw(File::Spec::Unix);
 
 sub case_tolerant { 1 }
 
@@ -121,7 +116,7 @@ doesn't alter the path, i.e. these arguments are ignored. (When a ""
 is passed as the first argument, it has a special meaning, see
 (6)). This way, a colon ":" is handled like a "." (curdir) on Unix,
 while an empty string "" is generally ignored (see
-C<Unix-E<gt>canonpath()> ). Likewise, a "::" is handled like a ".."
+L<File::Spec::Unix/canonpath()> ). Likewise, a "::" is handled like a ".."
 (updir), and a ":::" is handled like a "../.." etc.  E.g.
 
     catdir("a",":",":","b")   = ":a:b:"
@@ -156,16 +151,19 @@ their Unix counterparts:
  Unix:
     Unix->catdir("","")                 =  "/"
     Unix->catdir("",".")                =  "/"
-    Unix->catdir("","..")               =  "/"              # can't go beyond root
+    Unix->catdir("","..")               =  "/"        # can't go
+                                                      # beyond root
     Unix->catdir("",".","..","..","a")  =  "/a"
  Mac:
-    Mac->catdir("","")                  =  rootdir()         # (e.g. "HD:")
+    Mac->catdir("","")                  =  rootdir()  # (e.g. "HD:")
     Mac->catdir("",":")                 =  rootdir()
-    Mac->catdir("","::")                =  rootdir()         # can't go beyond root
-    Mac->catdir("",":","::","::","a")   =  rootdir() . "a:"  # (e.g. "HD:a:")
+    Mac->catdir("","::")                =  rootdir()  # can't go
+                                                      # beyond root
+    Mac->catdir("",":","::","::","a")   =  rootdir() . "a:"
+                                                    # (e.g. "HD:a:")
 
 However, this approach is limited to the first arguments following
-"root" (again, see C<Unix-E<gt>canonpath()> ). If there are more
+"root" (again, see L<File::Spec::Unix/canonpath()>. If there are more
 arguments that move up the directory tree, an invalid path going
 beyond root can be created.
 
@@ -340,27 +338,11 @@ sub devnull {
 
 =item rootdir
 
-Returns a string representing the root directory.  Under MacPerl,
-returns the name of the startup volume, since that's the closest in
-concept, although other volumes aren't rooted there. The name has a
-trailing ":", because that's the correct specification for a volume
-name on Mac OS.
-
-If Mac::Files could not be loaded, the empty string is returned.
+Returns the empty string.  Mac OS has no real root directory.
 
 =cut
 
-sub rootdir {
-#
-#  There's no real root directory on Mac OS. The name of the startup
-#  volume is returned, since that's the closest in concept.
-#
-    return '' unless $macfiles;
-    my $system = Mac::Files::FindFolder(&Mac::Files::kOnSystemDisk,
-	&Mac::Files::kSystemFolderType);
-    $system =~ s/:.*\Z(?!\n)/:/s;
-    return $system;
-}
+sub rootdir { '' }
 
 =item tmpdir
 
@@ -371,10 +353,10 @@ directory on your startup volume.
 
 =cut
 
-my $tmpdir;
 sub tmpdir {
-    return $tmpdir if defined $tmpdir;
-    $tmpdir = $_[0]->_tmpdir( $ENV{TMPDIR} );
+    my $cached = $_[0]->_cached_tmpdir('TMPDIR');
+    return $cached if defined $cached;
+    $_[0]->_cache_tmpdir($_[0]->_tmpdir( $ENV{TMPDIR} ), 'TMPDIR');
 }
 
 =item updir
@@ -400,10 +382,11 @@ the filename '' is always considered to be absolute. Note that with version
 
 E.g.
 
-    File::Spec->file_name_is_absolute("a");             # false (relative)
-    File::Spec->file_name_is_absolute(":a:b:");         # false (relative)
-    File::Spec->file_name_is_absolute("MacintoshHD:");  # true (absolute)
-    File::Spec->file_name_is_absolute("");              # true (absolute)
+    File::Spec->file_name_is_absolute("a");         # false (relative)
+    File::Spec->file_name_is_absolute(":a:b:");     # false (relative)
+    File::Spec->file_name_is_absolute("MacintoshHD:");
+                                                    # true (absolute)
+    File::Spec->file_name_is_absolute("");          # true (absolute)
 
 
 =cut
@@ -440,7 +423,8 @@ sub path {
 =item splitpath
 
     ($volume,$directories,$file) = File::Spec->splitpath( $path );
-    ($volume,$directories,$file) = File::Spec->splitpath( $path, $no_file );
+    ($volume,$directories,$file) = File::Spec->splitpath( $path,
+                                                          $no_file );
 
 Splits a path into volume, directory, and filename portions.
 
@@ -664,7 +648,7 @@ sub abs2rel {
 
     # Figure out the effective $base and clean it up.
     if ( !defined( $base ) || $base eq '' ) {
-	$base = $self->_cwd();
+	$base = Cwd::getcwd();
     }
     elsif ( ! $self->file_name_is_absolute( $base ) ) {
         $base = $self->rel2abs( $base ) ;
@@ -683,7 +667,7 @@ sub abs2rel {
     # Now, remove all leading components that are the same
     my @pathchunks = $self->splitdir( $path_dirs );
     my @basechunks = $self->splitdir( $base_dirs );
-
+	
     while ( @pathchunks &&
 	    @basechunks &&
 	    lc( $pathchunks[0] ) eq lc( $basechunks[0] ) ) {
@@ -732,7 +716,7 @@ sub rel2abs {
     if ( ! $self->file_name_is_absolute($path) ) {
         # Figure out the effective $base and clean it up.
         if ( !defined( $base ) || $base eq '' ) {
-	    $base = $self->_cwd();
+	    $base = Cwd::getcwd();
         }
         elsif ( ! $self->file_name_is_absolute($base) ) {
             $base = $self->rel2abs($base) ;
@@ -740,7 +724,7 @@ sub rel2abs {
 
 	# Split up paths
 
-	# igonore $path's volume
+	# ignore $path's volume
         my ( $path_dirs, $path_file ) = ($self->splitpath($path))[1,2] ;
 
         # ignore $base's file part
