@@ -13,7 +13,7 @@ use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
 use version;
 
 use vars qw[$VERSION];
-$VERSION = "0.9914";
+$VERSION = "0.9916";
 
 local $Params::Check::VERBOSE = 1;
 
@@ -397,13 +397,14 @@ Returns the user's homedir, or C<cwd> if it could not be found
 sub _home_dir {
 
     if ( can_load( modules => { 'File::HomeDir' => 0.0 } ) ) {
-      if ( defined $ENV{APPDATA} && length $ENV{APPDATA} && !ON_WIN32 ) {
-        msg("'APPDATA' env var is set and not on MSWin32, " .
+      if ( defined $ENV{APPDATA} && length $ENV{APPDATA} && !(ON_WIN32 or ON_CYGWIN) ) {
+        msg("'APPDATA' env var is set and not on MSWin32 or cygwin, " .
             "please use 'PERL5_CPANPLUS_HOME' instead to change .cpanplus location", 1 );
       }
       return File::HomeDir->my_home if -d File::HomeDir->my_home;
     }
 
+  # Note: "USERPROFILE" is a MSWin32 thing and "HOME" is *not*.
     my @os_home_envs = qw( APPDATA HOME USERPROFILE WINDIR SYS$LOGIN );
 
     for my $env ( @os_home_envs ) {
